const fs = require("fs");
const path = require("path");

// NOTE: Next.js does something super weird in production/standalone mode where process.env is cleared
// of system process.env. The only reasonable workaround I found for this is to dump an .env file
// in the deployment directory before running server (next.js loads this into process.env automatically)
const envVars = [
  "DATA_PATH",
  // TODO: more
];

console.log("Preparing env variables…");

const envDeclarations = envVars
  .map((name) => {
    const val = process.env[name];
    if (!val) {
      throw new Error(`Missing env variable ${name}`);
    }
    return `${name}=${val}`;
  })
  .join("\n");

const shouldOutputHere = process.argv.includes('--docker')
const outputDir = shouldOutputHere ? '' : '.next/standalone'

console.log(`Dumping env variables to ${outputDir}...`);
const envPath = path.join(__dirname, "..", outputDir, ".env");
fs.writeFileSync(envPath, envDeclarations);
